package com.sun.org.apache.xerces.internal.impl.dtd.models;

import com.sun.org.apache.xerces.internal.xni.QName;

public class MixedContentModel implements ContentModelValidator
{
    private int fCount;
    private QName[] fChildren;
    private int[] fChildrenType;
    private boolean fOrdered;
    
    public MixedContentModel(QName[] children, int[] type, int offset, int length, boolean ordered) {
        this.fCount = length;
        this.fChildren = new QName[this.fCount];
        this.fChildrenType = new int[this.fCount];
        for (int i = 0; i < this.fCount; ++i) {
            this.fChildren[i] = new QName(children[offset + i]);
            this.fChildrenType[i] = type[offset + i];
        }
        this.fOrdered = ordered;
    }
    
    @Override
    public int validate(QName[] children, int offset, int length) {
        if (this.fOrdered) {
            int inIndex2 = 0;
            for (int outIndex2 = 0; outIndex2 < length; ++outIndex2) {
                QName curChild2 = children[offset + outIndex2];
                if (curChild2.localpart != null) {
                    int type = this.fChildrenType[inIndex2];
                    if (type == 0) {
                        if (this.fChildren[inIndex2].rawname != children[offset + outIndex2].rawname) {
                            return outIndex2;
                        }
                    }
                    else if (type == 6) {
                        String uri = this.fChildren[inIndex2].uri;
                        if (uri != null && uri != children[outIndex2].uri) {
                            return outIndex2;
                        }
                    }
                    else if (type == 8) {
                        if (children[outIndex2].uri != null) {
                            return outIndex2;
                        }
                    }
                    else if (type == 7 && this.fChildren[inIndex2].uri == children[outIndex2].uri) {
                        return outIndex2;
                    }
                    ++inIndex2;
                }
            }
        }
        else {
            for (int outIndex = 0; outIndex < length; ++outIndex) {
                QName curChild = children[offset + outIndex];
                if (curChild.localpart != null) {
                    int inIndex;
                    for (inIndex = 0; inIndex < this.fCount; ++inIndex) {
                        int type = this.fChildrenType[inIndex];
                        if (type == 0) {
                            if (curChild.rawname == this.fChildren[inIndex].rawname) {
                                break;
                            }
                        }
                        else if (type == 6) {
                            String uri = this.fChildren[inIndex].uri;
                            if (uri != null) {
                                if (uri == children[outIndex].uri) {
                                    break;
                                }
                            }
                            else {
                                break;
                            }
                        }
                        else if (!((type != 8) ? (type != 7 || this.fChildren[inIndex].uri == children[outIndex].uri) : (children[outIndex].uri != null))) {
                            break;
                        }
                    }
                    if (inIndex == this.fCount) {
                        return outIndex;
                    }
                }
            }
        }
        return -1;
    }
}
